@@ -8,13 +8,13 @@
 
 #
 # not support
-# 
-return if feed? || @conf.mobile_agent?
+#
+return if feed?
 
 if /\A(?:form|preview|append|edit|update)\z/ =~ @mode
-   enable_js('http://ajax.googleapis.com/ajax/libs/jqueryui/1.8/jquery-ui.min.js')
+   enable_js('//ajax.googleapis.com/ajax/libs/jqueryui/1.11.4/jquery-ui.min.js')
    if @conf.lang == 'ja'
-      enable_js('http://ajax.googleapis.com/ajax/libs/jqueryui/1/i18n/jquery.ui.datepicker-ja.min.js')
+      enable_js('//ajax.googleapis.com/ajax/libs/jqueryui/1/i18n/jquery.ui.datepicker-ja.min.js')
    end
    enable_js('datepicker.js')
 end
