@@ -1,3 +1,4 @@
+# coding: utf-8
 # image_plugin_ex.rb
 # version 0.3
 # -pv-
@@ -86,11 +87,11 @@
 
 enable_js("image_ex.js")
 
-add_body_enter_proc(Proc.new do |date|
+add_body_enter_proc do |date|
 	@image_date = date.strftime("%Y%m%d")
 	@image_year = date.strftime("%Y")
 	""
-end)
+end
 
 
 def image( id, alt = "image", id2 = nil, width = nil, place="none" )
@@ -199,7 +200,7 @@ add_form_proc do |date|
 					imageex_convertedsize = %Q[#{imageex_convertedheight}x#{imageex_convertedwidth}]
 					imageex_convertedsize
 				end
-				system(imageex_convertpath , "-geometry", imageex_convertedsize , orig, new)
+				system(imageex_convertpath , "-auto-orient", "-geometry", imageex_convertedsize , orig, new)
 				if FileTest::size?( new ) == 0
 					File::delete( new )
 				end
