@@ -12,7 +12,7 @@ class MakeRssCategory < MakeRssFull
 	def title
 		'(category only)'
 	end
-	
+
 	def item( seq, body, rdfsec )
 		return unless rdfsec.section.respond_to?( :body_to_html )
 		return if rdfsec.section.categories.length == 0
@@ -22,17 +22,17 @@ class MakeRssCategory < MakeRssFull
 			end
 		end
 	end
-	
+
 	def file
 		f = @conf['makerss.category.file'] || 'category.rdf'
 		f = 'category.rdf' if f.length == 0
-		f
+		f =~ %r|^/| ? f : "#{document_root}/#{f}"
 	end
-	
+
 	def write( encoder )
 		super( encoder )
 	end
-	
+
 	def url
 		u = @conf['makerss.category.url'] || "#{@conf.base_url}category.rdf"
 		u = "#{@conf.base_url}category.rdf" if u.length == 0
@@ -40,4 +40,4 @@ class MakeRssCategory < MakeRssFull
 	end
 end
 
-@makerss_rsses << MakeRssCategory::new( @conf )
+@makerss_rsses << MakeRssCategory::new( @conf, @cgi )
