@@ -49,19 +49,19 @@ class PluginFake
 		@conf_procs << block
 	end
 
-	def add_edit_proc( block = Proc::new )
+	def add_edit_proc(&block)
 		@edit_procs << block
 	end
 
-	def add_header_proc( block = Proc::new )
+	def add_header_proc(&block)
 		@header_procs << block
 	end
 
-	def add_footer_proc( block = Proc::new )
+	def add_footer_proc(&block)
 		@footer_procs << block
 	end
 
-	def add_update_proc( block = Proc::new )
+	def add_update_proc(&block)
 		@update_procs << block
 	end
 
@@ -89,7 +89,7 @@ class PluginFake
 		r.join.chomp
 	end
 
-	def add_body_enter_proc( block = Proc::new )
+	def add_body_enter_proc(&block)
 		@body_enter_procs << block
 	end
 
@@ -101,7 +101,7 @@ class PluginFake
 		r.join.chomp
 	end
 
-	def add_body_leave_proc( block = Proc::new )
+	def add_body_leave_proc(&block)
 		@body_leave_procs << block
 	end
 
